@@ -1,10 +1,12 @@
 cross.cor.MSAR <-
-function(data,X=NULL,nc1=1,nc2=2,lag=10,regime=0,CI = FALSE,Bsim=0,N.samples=1,add=FALSE,col=1,names = NULL,alpha=.1,ylab="Cross-Correlation") {
-	if (is.null(X)) {X = 0*data[,,1]+1}
-	m1 = mean(data[,,nc1][X!=regime])
-	sd1 = sd(data[,,nc1][X!=regime])
-	m2 = mean(data[,,nc2][X!=regime])
-	sd2 = sd(data[,,nc2][X!=regime])
+function(data,X=NULL,nc1=1,nc2=2,lag=10,regime=0,CI = FALSE,Bsim=0,N.samples=1,add=FALSE,col=1,names = NULL,alpha=.1,ylab="Cross-Correlation",dt=1,ylim=c(-.1,1)) {
+	T = dim(data)[1]
+	N.samp = dim(data)[2]
+	if (is.null(X)) {X = array(1,c(T,N.samp,1))}
+	m1 = mean(data[,,nc1][X!=regime],na.rm=TRUE)
+	sd1 = sd(data[,,nc1][X!=regime],na.rm=TRUE)
+	m2 = mean(data[,,nc2][X!=regime],na.rm=TRUE)
+	sd2 = sd(data[,,nc2][X!=regime],na.rm=TRUE)
 	s.cc = matrix(0,1,length(-lag:lag))
 	n.obs = matrix(0,1,length(-lag:lag))	
 	T = dim(data)[1]
@@ -38,21 +40,21 @@ function(data,X=NULL,nc1=1,nc2=2,lag=10,regime=0,CI = FALSE,Bsim=0,N.samples=1,a
 			}}
 	}
 	if (add==FALSE) {
-		plot(-lag:lag,s.cc/n.obs/sd1/sd2,typ="l",ylab=ylab,xlab="Lag (day)",ylim=c(-.1,1),col=col,lwd=2)
+		plot((-lag:lag)*dt,s.cc/n.obs/sd1/sd2,typ="l",ylab=ylab,xlab="Lag (day)",ylim=ylim,col=col,lwd=2)
 		grid()
 		if (!is.null(names)){title(paste(names[nc1],", ",names[nc2],sep=""))}
 	} else {
-		lines(-lag:lag,s.cc/n.obs/sd1/sd2,col=col)
+		lines((-lag:lag)*dt,s.cc/n.obs/sd1/sd2,col=col)
 	}
-        if (CI==TRUE) {
+    if (CI==TRUE) {
 			IC = matrix(0,2*lag+1,2)
         	for (k in 1:(2*lag+1)) {
         		tmp.cc = diff(S.CC[1:(Bsim+1),k])
         		tmp.obs = diff(N.OBS[1:(Bsim+1),k])
         		IC[k,] = quantile(tmp.cc/tmp.obs,probs=c(alpha/2,1-alpha/2)) 
         	}
-        	lines(-lag:lag,IC[,1]/sd1/sd2,lty=2,col=col)
-        	lines(-lag:lag,IC[,2]/sd1/sd2,lty=2,col=col)
+        	lines((-lag:lag)*dt,IC[,1]/sd1/sd2,lty=2,col=col)
+        	lines((-lag:lag)*dt,IC[,2]/sd1/sd2,lty=2,col=col)
         } else {IC = NULL}
-     list(ccf=s.cc/n.obs/sd1/sd2,lag=-lag:lag,CI=IC)
+     list(ccf=s.cc/n.obs/sd1/sd2,lag=-lag:lag,CI=IC/sd1/sd2)
 }
